/***************************************************************************
 *   Copyright (C) 2004 by Diego 'Flameeyes' Petteno                       *
 *   dgp85@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KDIGESTMD5SUMFILE_H
#define KDIGESTMD5SUMFILE_H

#include "digestfile.h"

#include <kmdcodec.h>

namespace KDigest {

/**
@author Diego 'Flameeyes' Petteno
@brief Class representing an MD5SUM file

This class is derived from DigestFile, which defines all the base infos about the file itself.
*/
class MD5SUMfile : public DigestFile
{
Q_OBJECT
public:
	/// An SFV entry
	class MD5SUMentry : public DigestFile::DigestEntry {
		public:
			MD5SUMentry() { }
			MD5SUMentry(const QString &filepath);
			virtual ~MD5SUMentry() { };
			
			KMD5::Digest md5;	///< Declared MD5 of the file
			KMD5::Digest aMd5;	///< Actual MD5 of the file (should be 0 if not tested)
			
			/// Gets a string for the given digest of the file
			const QString digest() const
			{
				const uint32_t *md5Bytes = reinterpret_cast<const uint32_t*>(md5);
				QString str;
				return str.sprintf(
					"%08x%08x%08x%08x",
					md5Bytes[0],
					md5Bytes[1],
					md5Bytes[2],
					md5Bytes[3]
					);
			}
			
			/// Gets a string for the actual digest of the file
			const QString actual() const
			{
				const uint32_t *md5Bytes = reinterpret_cast<const uint32_t*>(aMd5);
				QString str;
				return str.sprintf(
					"%08x%08x%08x%08x",
					md5Bytes[0],
					md5Bytes[1],
					md5Bytes[2],
					md5Bytes[3]
					);
			}
			
			bool calculateActual(const QString &filename);
			void writeOnFile(QFile &file);
			
			inline static KMD5 &getDigest(QFile &f, KMD5 &context);
	};
	
	MD5SUMfile(const QString &path, QObject *parent = NULL, const char *name = NULL);
	MD5SUMfile(QObject *parent = NULL, const char *name = NULL)
		: DigestFile(parent, name)
	{ }
	
	~MD5SUMfile();
	
	void addFile(const QString &filename);
};

};

#endif
