/***************************************************************************
 *   Copyright (C) 2004 by Diego 'Flameeyes' Petteno                       *
 *   dgp85@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef SFVFILE_H
#define SFVFILE_H

#include "digestfile.h"

namespace KDigest {

/**
@author Diego 'Flameeyes' Petten
@brief Class representing a SFV file

This class is derived from DigestFile, which defines all the base infos about the file itself.
*/
class SFVfile : public DigestFile {
Q_OBJECT
public:
	/// An SFV entry
	class SFVentry : public DigestFile::DigestEntry {
		public:
			SFVentry() { }
			SFVentry(const QString &filepath);
			virtual ~SFVentry() { };
			uint32_t crc32;		///< CRC32 of the file
			uint32_t aCrc32;	///< Actual CRC32 of the file (should be 0 if not tested)
			
			/// Gets a string for the given digest of the file
			const QString digest() const
			{ return QString::number( crc32, 16 ); }
			
			/// Gets a string for the actual digest of the file
			const QString actual() const
			{ return QString::number( aCrc32, 16 ); }
			
			bool calculateActual(const QString &filename);
			void writeOnFile(QFile &file);
			
			inline static const uint32_t getDigest(QFile &f);
	};
	
	SFVfile(const QString &path, QObject *parent = NULL, const char *name = NULL);
	SFVfile(QObject *parent = NULL, const char *name = NULL)
		: DigestFile(parent, name)
	{ }
	
	~SFVfile();
	
	void addFile(const QString &filename);
	bool saveDigest(const QString &filename);
protected:
	QString m_comments;	///< Comments in the file
};

};

#endif
